@@ -62,6 +62,7 @@ import qualified Data.List as List
 import Data.List.NonEmpty (NonEmpty)
 import Data.Functor.Identity (Identity)
 import Data.Map (Map)
+import qualified Data.Map.Strict as Map
 import Data.HashMap.Strict (HashMap)
 import Data.Vector (Vector)
 import Control.Monad.Trans.Maybe (MaybeT (..))
@@ -141,7 +142,8 @@ type instance Element (Arg a b) = b
 class MonoFunctor mono where
     -- | Map over a monomorphic container
     omap :: (Element mono -> Element mono) -> mono -> mono
-    default omap :: (Functor f, Element (f a) ~ a, f a ~ mono) => (a -> a) -> f a -> f a
+    default omap :: (Functor f, Element (f a) ~ a, f a ~ mono)
+                 => (Element mono -> Element mono) -> mono -> mono
     omap = fmap
     {-# INLINE omap #-}
 
@@ -332,7 +334,7 @@ class MonoFoldable mono where
     -- /See 'Data.NonNull.ofoldr1Ex' from "Data.NonNull" for a total version of this function./
     ofoldr1Ex :: (Element mono -> Element mono -> Element mono) -> mono -> Element mono
     default ofoldr1Ex :: (t a ~ mono, a ~ Element (t a), F.Foldable t)
-                           => (a -> a -> a) -> mono -> a
+                      => (Element mono -> Element mono -> Element mono) -> mono -> Element mono
     ofoldr1Ex = F.foldr1
     {-# INLINE ofoldr1Ex #-}
 
@@ -345,7 +347,7 @@ class MonoFoldable mono where
     -- /See 'Data.NonNull.ofoldl1Ex'' from "Data.NonNull" for a total version of this function./
     ofoldl1Ex' :: (Element mono -> Element mono -> Element mono) -> mono -> Element mono
     default ofoldl1Ex' :: (t a ~ mono, a ~ Element (t a), F.Foldable t)
-                            => (a -> a -> a) -> mono -> a
+                       => (Element mono -> Element mono -> Element mono) -> mono -> Element mono
     ofoldl1Ex' = F.foldl1
     {-# INLINE ofoldl1Ex' #-}
 
@@ -597,7 +599,9 @@ instance MonoFoldable (IntMap a)
 instance MonoFoldable (Option a)
 instance MonoFoldable (NonEmpty a)
 instance MonoFoldable (Identity a)
-instance MonoFoldable (Map k v)
+instance MonoFoldable (Map k v) where
+    olength = Map.size
+    {-# INLINE olength #-}
 instance MonoFoldable (HashMap k v)
 instance MonoFoldable (Vector a) where
     ofoldr = V.foldr
@@ -629,7 +633,9 @@ instance MonoFoldable (Vector a) where
     {-# INLINE unsafeHead #-}
     {-# INLINE maximumByEx #-}
     {-# INLINE minimumByEx #-}
-instance MonoFoldable (Set e)
+instance MonoFoldable (Set e) where
+    olength = Set.size
+    {-# INLINE olength #-}
 instance MonoFoldable (HashSet e)
 
 instance U.Unbox a => MonoFoldable (U.Vector a) where
@@ -836,7 +842,7 @@ onotElem e = List.notElem e . otoList
 {-# INLINE [0] onotElem #-}
 
 {-# RULES "strict ByteString elem" oelem = S.elem #-}
-{-# RULES "strict ByteString notElem" oelem = S.notElem #-}
+{-# RULES "strict ByteString notElem" onotElem = S.notElem #-}
 
 {-# RULES "lazy ByteString elem" oelem = L.elem #-}
 {-# RULES "lazy ByteString notElem" oelem = L.notElem #-}
